netapp_ontap.models.usm API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.usm`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class UsmSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Usm object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `authentication_password: str POST`

    Authentication protocol password.

    Example: humTdumt*@t0nAwa11

  `authentication_protocol: str GET POST PATCH`

    Authentication protocol.

    Valid choices:

    - none
    - md5
    - sha
    - sha2_256
  `links: SelfLink GET`

    The links field of the usm.

  `privacy_password: str POST`

    Privacy protocol password.

    Example: p@*GOandCLCt200

  `privacy_protocol: str GET POST PATCH`

    Privacy protocol.

    Valid choices:

    - none
    - des
    - aes128